@@ -1,5 +1,5 @@
 package Net::Twitter::Role::API::RESTv1_1;
-$Net::Twitter::Role::API::RESTv1_1::VERSION = '4.01010';
+$Net::Twitter::Role::API::RESTv1_1::VERSION = '4.01043';
 use Moose::Role;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use Net::Twitter::API;
@@ -62,7 +62,7 @@ user specified by C<screen_name> or C<user_id>.
 twitter_api_method home_timeline => (
     description => <<'',
 Returns the 20 most recent statuses, including retweets, posted by the
-authenticating user and that user's friends. 
+authenticating user and that user's friends.
 
     path      => 'statuses/home_timeline',
     method    => 'GET',
@@ -77,7 +77,7 @@ authenticating user and that user's friends.
 twitter_api_method friends_timeline => (
     description => <<'',
 Returns the 20 most recent statuses, including retweets, posted by the
-authenticating user and that user's friends. 
+authenticating user and that user's friends.
 
     path      => 'statuses/home_timeline',
     aliases   => [qw/following_timeline/],
@@ -132,7 +132,10 @@ authenticating user must be the author of the specified status.
 twitter_api_method update => (
     path       => 'statuses/update',
     method     => 'POST',
-    params     => [qw/media_ids status lat long place_id display_coordinates in_reply_to_status_id trim_user/],
+    params     => [qw/
+        attachment_url display_coordinates in_reply_to_status_id lat long
+        media_ids place_id status trim_user
+    /],
     required   => [qw/status/],
     booleans   => [qw/display_coordinates trim_user/],
     add_source => 1,
@@ -193,7 +196,7 @@ EOT
 
 twitter_api_method retweet => (
     description => <<'',
-Retweets a tweet. 
+Retweets a tweet.
 
     path      => 'statuses/retweet/:id',
     method    => 'POST',
@@ -204,6 +207,7 @@ Retweets a tweet.
 );
 
 twitter_api_method update_with_media => (
+    deprecated  => 1,
     path        => 'statuses/update_with_media',
     method      => 'POST',
     params      => [qw/
@@ -215,6 +219,10 @@ twitter_api_method update_with_media => (
     description => <<'EOT',
 Updates the authenticating user's status and attaches media for upload.
 
+Note that Twitter has marked this endpoint as B<deprecated>, and recommends
+instead calling C<upload>, then (optionally) C<create_media_metadata>, then
+C<update>.
+
 The C<media[]> parameter is an arrayref with the following interpretation:
 
   [ $file ]
@@ -234,7 +242,7 @@ C<undef> as the first array value.
 The Tweet text will be rewritten to include the media URL(s), which will reduce
 the number of characters allowed in the Tweet text. If the URL(s) cannot be
 appended without text truncation, the tweet will be rejected and this method
-will return an HTTP 403 error. 
+will return an HTTP 403 error.
 EOT
 
 );
@@ -702,8 +710,8 @@ user credentials are valid.
 
     path     => 'account/verify_credentials',
     method   => 'GET',
-    params   => [qw/include_entities skip_status/],
-    booleans => [qw/include_entities skip_status/],
+    params   => [qw/include_entities skip_status include_email/],
+    booleans => [qw/include_entities skip_status include_email/],
     required => [qw//],
     returns  => 'ExtendedUser',
 );
@@ -862,7 +870,7 @@ out more about blocking in the Twitter Support Knowledge Base.
     path     => 'blocks/create',
     method   => 'POST',
     params   => [qw/user_id screen_name include_entities skip_status/],
-    booleans => [qw/include_entities skip_status/],    
+    booleans => [qw/include_entities skip_status/],
     required => [qw/id/],
     returns  => 'BasicUser',
 );
@@ -945,6 +953,7 @@ the first 1000 matches from this API.
 );
 
 twitter_api_method contributees => (
+    deprecated  => 1,
     path        => 'users/contributees',
     method      => 'GET',
     params      => [qw/user_id screen_name include_entities skip_satus/],
@@ -957,6 +966,7 @@ Returns an array of users that the specified user can contribute to.
 );
 
 twitter_api_method contributors => (
+    deprecated  => 1,
     path        => 'users/contributors',
     method      => 'GET',
     params      => [qw/user_id screen_name include_entities skip_satus/],
@@ -982,32 +992,45 @@ require authentication.
 );
 
 twitter_api_method user_suggestions_for => (
-    aliases     => [qw/follow_suggestions/],
-    path        => 'users/suggestions/:category',
+    aliases     => [qw/follow_suggestions_for/],
+    path        => 'users/suggestions/:slug',
     method      => 'GET',
-    params      => [qw/category lang/],
-    required    => [qw/category/],
+    params      => [qw/slug lang/],
+    required    => [qw/slug/],
     returns     => 'ArrayRef',
     description => <<''
-Access the users in a given category of the Twitter suggested user list.
+Access the users in a given slug (category) of the Twitter suggested user list.
 
 );
 
 twitter_api_method user_suggestions => (
     aliases     => [qw/follow_suggestions/],
-    path        => 'users/suggestions/:category/members',
+    path        => 'users/suggestions/:slug/members',
     method      => 'GET',
-    params      => [qw/category lang/],
-    required    => [qw/category/],
+    params      => [qw/slug lang/],
+    required    => [qw/slug/],
     returns     => 'ArrayRef',
     description => <<''
-Access the users in a given category of the Twitter suggested user list and
-return their most recent status if they are not a protected user. Currently
-supported values for optional parameter C<lang> are C<en>, C<fr>, C<de>, C<es>,
-C<it>.  Does not require authentication.
+Access the users in a given slug (category) of the Twitter suggested user list
+and return their most recent status if they are not a protected user.
+Currently supported values for optional parameter C<lang> are C<en>, C<fr>,
+C<de>, C<es>, C<it>.  Does not require authentication.
 
 );
 
+# backwards compatibility: Twitter renamed "category" to "slug"
+around [ qw/follow_suggestions follow_suggestions_for user_suggestions
+user_suggestions_for/ ] => sub {
+    my ( $next, $self ) = splice @_, 0, 2;
+
+    my $args = ref $_[-1] eq 'HASH' ? pop : {};
+    if ( exists $args->{category} ) {
+        $args->{slug} = delete $args->{category};
+    }
+
+    return $self->$next(@_, $args);
+};
+
 twitter_api_method favorites => (
     description => <<'',
 Returns the 20 most recent favorite statuses for the authenticating
@@ -1392,13 +1415,27 @@ twitter_api_method geo_id => (
     description => <<'',
 Returns details of a place returned from the C<reverse_geocode> method.
 
-    path => 'geo/id/:id',
-    method => 'GET',
-    params => [qw/id/],
-    required => [qw/id/],
+    path     => 'geo/id/:place_id',
+    method   => 'GET',
+    params   => [qw/place_id/],
+    required => [qw/place_id/],
     returns  => 'HashRef',
 );
 
+# backwards compat for 'geo/id/:id'
+# recast to 'geo/id/:place_id
+around geo_id => sub {
+    my ( $next, $self ) = splice @_, 0, 2;
+
+    my $args = ref $_[-1] eq 'HASH' ? pop @_ : {};
+
+    if ( exists $args->{id} ) {
+        $args->{place_id} = delete $args->{id};
+    }
+
+    return $self->$next(@_, $args);
+};
+
 twitter_api_method reverse_geocode => (
     description => <<EOT,
 Search for places (cities and neighborhoods) that can be attached to a
@@ -1562,7 +1599,7 @@ ID L<http://developer.yahoo.com/geo/geoplanet/>) and some other human-readable
 information such as a the location's canonical name and country.
 
 For backwards compatibility, this method accepts optional C<lat> and C<long>
-parameters. You should call C<trends_closest> directly, instead. 
+parameters. You should call C<trends_closest> directly, instead.
 
 Use the WOEID returned in the location object to query trends for a specific
 location.
@@ -1690,7 +1727,7 @@ EOT
     returns  => 'RateLimitStatus',
 );
 
-# translate resources arrayref to a comma separated string 
+# translate resources arrayref to a comma separated string
 around rate_limit_status => sub {
     my $orig = shift;
     my $self = shift;
@@ -2102,6 +2139,24 @@ Returns a hash reference of tweets from an arbitrary set of ids.
     returns  => 'HashRef',
 );
 
+twitter_api_method create_media_metadata => (
+    path        => 'media/metadata/create',
+    method      => 'POST',
+    params      => [qw/media_id alt_text/],
+    required    => [qw/media_id/],
+    returns     => 'HashRef',
+    content_type => 'application/json',
+    description => <<'EOT',
+Adds metadata -- alt text, in particular -- to a previously uploaded media
+object, specified by its ID. (One knows this ID via the return value of the
+preceding C<upload> call.)
+
+The C<alt_text> parameter must have as its value a hashref containing a single
+key-value pair. The key must be C<text>, and the value is the alt text to assign
+to the media object. The text must be 400 characters or fewer in length.
+EOT
+);
+
 # infer screen_name or user_id from positional args for backwards compatibility
 # and convenience
 around [qw/
@@ -2143,7 +2198,7 @@ Net::Twitter::Role::API::RESTv1_1 - A definition of the Twitter REST API v1.1 as
 
 =head1 VERSION
 
-version 4.01010
+version 4.01043
 
 =head1 SYNOPSIS
 
@@ -2164,7 +2219,7 @@ Marc Mims <marc@questright.com>
 
 =head1 LICENSE
 
-Copyright (c) 2009 Marc Mims
+Copyright (c) 2016 Marc Mims
 
 The Twitter API itself, and the description text used in this module is:
 
